type S2 = Proxy ( '[ '[], '[] ])
type S4 = Proxy ( '( 'Just, ' T'T))
type S5 = Proxy ( '[ 'Just, ' TT'T])
type S6 = Proxy ( '( '(), '() ))
type S7 = Proxy ( '( 'a, 'b ))
type S8 = Proxy ( '[ Int, Bool ])

type E = TypeError ('Text "Some text")
type G = '[ '( 'Just, 'Bool) ]

type X = () '`PromotedInfix` ()

type A = '[ 'a' ]
