{-|
Module:      Data.Aeson.TH
Copyright:   (c) 2011-2016 Bryan O'Sullivan
             (c) 2011 MailRank, Inc.
License:     BSD3
Stability:   experimental
Portability: portable
-}

module Main where

{- |

Here is a snippet:

@
x = y + 2
@

-}

x = y + 2
