{-# LANGUAGE ApplicativeDo       #-}
{-# LANGUAGE GHC2021             #-}
{-# LANGUAGE ScopedTypeVariables #-}
{-# LANGUAGE TypeFamilies        #-}
{-# LANGUAGE NondecreasingIndentation #-}
-- This gap is necessary for stylish Haskell not to re-arrange
-- NoMonoLocalBinds before TypeFamilies
{-# LANGUAGE NoMonoLocalBinds    #-}

module Foo (
   bar
  ) where
