foo =
  if x
    then
      -- comment 1
      -- comment 2
      case a of
        Just b -> _
        Nothing -> _
    else
      -- comment 3
      -- comment 4
      case a of
        Just b -> _
        Nothing -> _
