import Data.Text
import Data.Text
import qualified Data.Text as T
import qualified Data.Text (a, c, b)
import Data.Text (a, b, c)
import Data.Text hiding (c, b, a)
import Data.Text (a, b, c, b, a)
import Data.Text hiding (c, b, a, b, c)
