{-# LANGUAGE OverloadedStrings #-}
-- TODO This extension is probably too dangerous, remove it.
{-# LANGUAGE RecordWildCards #-}
-- Avoid warning produced by TH.
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}

-- | Header comment.
module Foo () where
