module Test (
        since1, -- ^ @since 1.0
        since2  -- ^ @since 2.0
      , since3  -- ^ @since 3.0
      , SinceType(..) -- ^ @since 4.0
      , SinceClass(..) -- ^ @since 5.0
      , Multi(..)
        -- ^ since 6.0
        -- multi
        -- line
      ) where
