-- | Header comment.

{-# LANGUAGE OverloadedStrings #-}

-- Avoid warning produced by TH.
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}

-- TODO This extension is probably too dangerous, remove it.
{-# LANGUAGE RecordWildCards #-}

module Foo () where
