{-# LANGUAGE GHC2021 #-}
{-# LANGUAGE ApplicativeDo #-}
{-# LANGUAGE NondecreasingIndentation #-}
{-# LANGUAGE ScopedTypeVariables #-}
{-# LANGUAGE TypeFamilies #-}
-- This gap is necessary for stylish Haskell not to re-arrange
-- NoMonoLocalBinds before TypeFamilies
{-# LANGUAGE NoMonoLocalBinds #-}

module Foo
  ( bar,
  )
where
