-- | Header comment.

{-# LANGUAGE LambdaCase #-}
{-#LANGuagE ViewPatterns #-}
{-# LANGUAGE OverloadedStrings#-}
{-# OPTIONS_GHC -Wall -Werror #-}
{-# language DataKinds, LambdaCase #-}
{-# OPTIONS_HADDOCK   prune, show-extensions #-}
{-# OPTIONS_GHC -O2 -H 300    #-}
{-# language IncoherentInstances
           , AllowAmbiguousTypes #-}

module Foo () where
